@@ -1,5 +1,5 @@
-/* ogg123.c by Kenneth Arnold <ogg123@arnoldnet.net> */
-/* Maintained by Stan Seibert <volsung@xiph.org> */
+/* ogg123.c by Kenneth Arnold <kcarnold-xiph@arnoldnet.net> */
+/* Maintained by Stan Seibert <volsung@xiph.org>, Monty <monty@xiph.org> */
 
 /********************************************************************
  *                                                                  *
@@ -8,16 +8,20 @@
  * THE GNU PUBLIC LICENSE 2, WHICH IS INCLUDED WITH THIS SOURCE.    *
  * PLEASE READ THESE TERMS BEFORE DISTRIBUTING.                     *
  *                                                                  *
- * THE Ogg123 SOURCE CODE IS (C) COPYRIGHT 2000-2001                *
- * by Kenneth C. Arnold <ogg@arnoldnet.net> AND OTHER CONTRIBUTORS  *
+ * THE Ogg123 SOURCE CODE IS (C) COPYRIGHT 2000-2005                *
+ * by Stan Seibert <volsung@xiph.org> AND OTHER CONTRIBUTORS        *
  * http://www.xiph.org/                                             *
  *                                                                  *
  ********************************************************************
 
- last mod: $Id: ogg123.c,v 1.70 2003/09/02 19:37:05 volsung Exp $
+ last mod: $Id$
 
  ********************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <sys/types.h>
 #include <string.h>
 #include <stdlib.h>
@@ -42,32 +46,33 @@
 #include "status.h"
 #include "playlist.h"
 #include "compat.h"
+#include "remote.h"
 
 #include "ogg123.h"
 #include "i18n.h"
 
+extern int exit_status; /* from status.c */
 
-void exit_cleanup ();
-void play (char *source_string);
+void play (const char *source_string);
 
+#define PRIMAGIC (2*2*2*2*3*3*3*5*7)
 /* take buffer out of the data segment, not the stack */
-#define AUDIO_CHUNK_SIZE 4096
-unsigned char convbuffer[AUDIO_CHUNK_SIZE];
-int convsize = AUDIO_CHUNK_SIZE;
+#define AUDIO_CHUNK_SIZE ((16384 + PRIMAGIC - 1)/ PRIMAGIC * PRIMAGIC)
+static unsigned char convbuffer[AUDIO_CHUNK_SIZE];
+static int convsize = AUDIO_CHUNK_SIZE;
 
 ogg123_options_t options;
 stat_format_t *stat_format;
-buf_t *audio_buffer;
+static buf_t *audio_buffer=NULL;
 
-audio_play_arg_t audio_play_arg;
+static audio_play_arg_t audio_play_arg;
 
 
 /* ------------------------- config file options -------------------------- */
 
 /* This macro is used to create some dummy variables to hold default values
    for the options. */
-#define INIT(type, value) type type##_##value = value
-INIT(int, 1);
+#define INIT(type, value) static type type##_##value = value
 INIT(int, 0);
 
 file_option_t file_opts[] = {
@@ -76,6 +81,8 @@ file_option_t file_opts[] = {
    &options.default_device, NULL},
   {0, "shuffle",        N_("shuffle playlist"),      opt_type_bool,
    &options.shuffle,        &int_0},
+  {0, "repeat",         N_("repeat playlist forever"),   opt_type_bool,
+   &options.repeat,         &int_0}, 
   {0, NULL,             NULL,                    0,               NULL,                NULL}
 };
 
@@ -108,6 +115,10 @@ void signal_handler (int signo)
     sig_request.last_ctrl_c = now;
     break;
 
+  case SIGTERM:
+    sig_request.exit = 1;
+    break;
+
   case SIGTSTP:
     sig_request.pause = 1;
     /* buffer_Pause (Options.outputOpts.buffer);
@@ -139,8 +150,9 @@ void options_init (ogg123_options_t *opts)
   opts->delay = 500;
   opts->nth = 1;
   opts->ntimes = 1;
-  opts->seekpos = 0.0;
+  opts->seekoff = 0.0;
   opts->endpos = -1.0; /* Mark as unset */
+  opts->seekmode = DECODER_SEEK_NONE;
   opts->buffer_size = 128 * 1024;
   opts->prebuffer = 0.0f;
   opts->input_buffer_size = 64 * 1024;
@@ -149,9 +161,85 @@ void options_init (ogg123_options_t *opts)
 
   opts->status_freq = 10.0;
   opts->playlist = NULL;
+  opts->remote = 0;
+  opts->repeat = 0;
 
 }
 
+double strtotime(char *s)
+{
+	double time;
+
+	time = strtod(s, &s);
+
+	while (*s == ':')
+		time = 60 * time + strtod(s + 1, &s);
+
+	return time;
+}
+
+void set_seek_opt(ogg123_options_t *ogg123_opts, char *buf) {
+
+  char *b = buf;
+
+  /* skip spaces */
+  while (*b && (*b == ' ')) b++;
+
+  if (*b == '-') {
+  /* relative seek back */
+    ogg123_opts->seekoff = -1 * strtotime(b+1);
+    ogg123_opts->seekmode = DECODER_SEEK_CUR;
+  } else
+  if (*b == '+') {
+  /* relative seek forward */
+    ogg123_opts->seekoff = strtotime(b+1);
+    ogg123_opts->seekmode = DECODER_SEEK_CUR;
+  } else {
+  /* absolute seek */
+    ogg123_opts->seekoff = strtotime(b);
+    ogg123_opts->seekmode = DECODER_SEEK_START;
+  }
+}
+
+int handle_seek_opt(ogg123_options_t *options, decoder_t *decoder, format_t *format) {
+
+  float pos=decoder->format->statistics(decoder)->current_time;
+
+  /* this functions handles a seek request. It prevents seeking out
+     of band, i.e. before the beginning or after the end. Instead,
+	 it seeks to the start or near-end resp. */
+
+  if (options->seekmode != DECODER_SEEK_NONE) {
+
+    if (options->seekmode == DECODER_SEEK_START) {
+      pos = options->seekoff;
+    } else {
+      pos += options->seekoff;
+    }
+
+    if (pos < 0) {
+      pos = 0;
+    }
+
+    if (pos > decoder->format->statistics(decoder)->total_time) {
+      /* seek to almost the end of the stream */
+      pos = decoder->format->statistics(decoder)->total_time - 0.01;
+    }
+
+    if (!format->seek(decoder, pos, DECODER_SEEK_START)) {
+      status_error(_("Could not skip to %f in audio stream."), options->seekoff);
+#if 0
+      /* Handle this fatally -- kill the audio thread */
+      if (audio_buffer != NULL)
+	buffer_thread_kill(audio_buffer);
+#endif
+    }
+  }
+
+  options->seekmode = DECODER_SEEK_NONE;
+
+  return 1;
+}
 
 /* This function selects which statistics to display for our
    particular configuration.  This does not have anything to do with
@@ -180,7 +268,8 @@ void select_stats (stat_format_t *stats, ogg123_options_t *opts,
     stats[6].enabled = 0;
     stats[7].enabled = 0;
   }
-    
+  free(data_source_stats);
+
   /* Assume we need total time display, and let display_statistics()
      determine at what point it should be turned off during playback */
   stats[2].enabled = 1;  /* Remaining playback time */
@@ -202,38 +291,47 @@ void display_statistics (stat_format_t *stat_format,
 					source->transport->statistics(source),
 					decoder->format->statistics(decoder));
 
-  /* Disable/Enable statistics as needed */
+  if (options.remote) {
 
-  if (pstats_arg->decoder_statistics->total_time <
-      pstats_arg->decoder_statistics->current_time) {
-    stat_format[2].enabled = 0;  /* Remaining playback time */
-    stat_format[3].enabled = 0;  /* Total playback time */
+    /* Display statistics via the remote interface */
+    remote_time(pstats_arg->decoder_statistics->current_time,
+                pstats_arg->decoder_statistics->total_time);
+
+  } else {
+
+	/* Disable/Enable statistics as needed */
+
+	if (pstats_arg->decoder_statistics->total_time <
+    	pstats_arg->decoder_statistics->current_time) {
+      stat_format[2].enabled = 0;  /* Remaining playback time */
+      stat_format[3].enabled = 0;  /* Total playback time */
+	}
+
+	if (pstats_arg->data_source_statistics->input_buffer_used) {
+      stat_format[6].enabled = 1;  /* Input buffer fill % */
+      stat_format[7].enabled = 1;  /* Input buffer state  */
+	}
+
+	if (audio_buffer) {
+      /* Place a status update into the buffer */
+      buffer_append_action_at_end(audio_buffer,
+				  &print_statistics_action,
+				  pstats_arg);
+
+      /* And if we are not playing right now, do an immediate
+    	 update just the output buffer */
+      buffer_stats = buffer_statistics(audio_buffer);
+      if (buffer_stats->paused || buffer_stats->prebuffering) {
+    	pstats_arg = new_print_statistics_arg(stat_format,
+					      NULL,
+					      NULL);
+    	print_statistics_action(audio_buffer, pstats_arg);
+      }
+      free(buffer_stats);
+
+	} else
+      print_statistics_action(NULL, pstats_arg);
   }
-
-  if (pstats_arg->data_source_statistics->input_buffer_used) {
-    stat_format[6].enabled = 1;  /* Input buffer fill % */
-    stat_format[7].enabled = 1;  /* Input buffer state  */
-  }
-
-  if (audio_buffer) {
-    /* Place a status update into the buffer */
-    buffer_append_action_at_end(audio_buffer,
-				&print_statistics_action,
-				pstats_arg);
-    
-    /* And if we are not playing right now, do an immediate
-       update just the output buffer */
-    buffer_stats = buffer_statistics(audio_buffer);
-    if (buffer_stats->paused || buffer_stats->prebuffering) {
-      pstats_arg = new_print_statistics_arg(stat_format,
-					    NULL,
-					    NULL);
-      print_statistics_action(audio_buffer, pstats_arg);
-    }
-    free(buffer_stats);
-    
-  } else
-    print_statistics_action(NULL, pstats_arg);
 }
 
 
@@ -273,7 +371,7 @@ void print_audio_devices_info(audio_device_t *d)
 
   while (d != NULL) {
     info = ao_driver_info(d->driver_id);
-    
+
     status_message(2, _("\nAudio Device:   %s"), info->name);
     status_message(3, _("Author:   %s"), info->author);
     status_message(3, _("Comments: %s"), info->comment);
@@ -320,7 +418,7 @@ int main(int argc, char **argv)
       if (S_ISDIR(stat_buf.st_mode)) {
 	if (playlist_append_directory(options.playlist, argv[i]) == 0)
 	  fprintf(stderr, 
-		  _("Warning: Could not read directory %s.\n"), argv[i]);
+		  _("WARNING: Could not read directory %s.\n"), argv[i]);
       } else {
 	playlist_append_file(options.playlist, argv[i]);
       }
@@ -342,13 +440,15 @@ int main(int argc, char **argv)
   }
 
   /* Don't use status_message until after this point! */
-  status_set_verbosity(options.verbosity);
+  status_init(options.verbosity);
 
   print_audio_devices_info(options.devices);
 
-  
-  /* Setup buffer */ 
+
+  /* Setup buffer */
   if (options.buffer_size > 0) {
+    /* Keep sample size alignment for surround sound with up to 10 channels */
+    options.buffer_size = (options.buffer_size + PRIMAGIC - 1) / PRIMAGIC * PRIMAGIC;
     audio_buffer = buffer_create(options.buffer_size,
 				 options.buffer_size * options.prebuffer / 100,
 				 audio_play_callback, &audio_play_arg,
@@ -361,44 +461,59 @@ int main(int argc, char **argv)
     audio_buffer = NULL;
 
 
-  /* Shuffle playlist */
-  if (options.shuffle) {
-    int i;
-    
-    srandom(time(NULL));
-    
-    for (i = 0; i < items; i++) {
-      int j = i + random() % (items - i);
-      char *temp = playlist_array[i];
-      playlist_array[i] = playlist_array[j];
-      playlist_array[j] = temp;
-    }
-  }
-
   /* Setup signal handlers and callbacks */
 
-  ATEXIT (exit_cleanup);
   signal (SIGINT, signal_handler);
   signal (SIGTSTP, signal_handler);
   signal (SIGCONT, signal_handler);
+  signal (SIGTERM, signal_handler);
 
+  if (options.remote) {
+    /* run the mainloop for the remote interface */
+    remote_mainloop();
 
-  /* Play the files/streams */
-  i = 0;
-  while (i < items && !sig_request.exit) {
-    play(playlist_array[i]);
-    i++;
+  } else {
+
+    do {
+      /* Shuffle playlist */
+      if (options.shuffle) {
+        int i;
+
+        srandom(time(NULL));
+
+        for (i = 0; i < items; i++) {
+          int j = i + random() % (items - i);
+          char *temp = playlist_array[i];
+          playlist_array[i] = playlist_array[j];
+          playlist_array[j] = temp;
+        }
+      }
+
+      /* Play the files/streams */
+      i = 0;
+      while (i < items && !sig_request.exit) {
+        play(playlist_array[i]);
+        i++;
+      }
+    } while (options.repeat);
+
+  }
+  playlist_array_destroy(playlist_array, items);
+  status_deinit();
+
+  if (audio_buffer != NULL) {
+    buffer_destroy (audio_buffer);
+    audio_buffer = NULL;
   }
 
-  playlist_array_destroy(playlist_array, items);
+  ao_onexit (options.devices);
 
-  exit (0);
+  exit (exit_status);
 }
 
-
-void play (char *source_string)
+void play (const char *source_string)
 {
-  transport_t *transport;
+  const transport_t *transport;
   format_t *format;
   data_source_t *source;
   decoder_t *decoder;
@@ -456,7 +571,7 @@ void play (char *source_string)
     status_error(_("The file format of %s is not supported.\n"), source_string);
     return;
   }
-  
+
   if ( (decoder = format->init(source, &options, &new_audio_fmt, 
 			       &decoder_callbacks,
 			       decoder_callbacks_arg)) == NULL ) {
@@ -474,7 +589,7 @@ void play (char *source_string)
 
   /* Start the audio playback thread before we begin sending data */    
   if (audio_buffer != NULL) {
-    
+
     /* First reset mutexes and other synchronization variables */
     buffer_reset (audio_buffer);
     buffer_thread_start (audio_buffer);
@@ -485,9 +600,15 @@ void play (char *source_string)
 				    _("Playing: %s"), source_string);
 
   /* Skip over audio */
-  if (options.seekpos > 0.0) {
-    if (!format->seek(decoder, options.seekpos, DECODER_SEEK_START)) {
-      status_error(_("Could not skip %f seconds of audio."), options.seekpos);
+  if (options.seekoff > 0.0) {
+    /* Note: it may be simpler to handle this condition by just calling:
+     *   handle_seek_opt(&options, decoder, format);
+     * which was introduced with the remote control interface. However, that
+     * function does not call buffer_thread_kill() on error, which is
+     * necessary in this situation.
+     */
+    if (!format->seek(decoder, options.seekoff, DECODER_SEEK_START)) {
+      status_error(_("Could not skip %f seconds of audio."), options.seekoff);
       if (audio_buffer != NULL)
 	buffer_thread_kill(audio_buffer);
       return;
@@ -496,18 +617,31 @@ void play (char *source_string)
 
   /* Main loop:  Iterates over all of the logical bitstreams in the file */
   while (!eof && !sig_request.exit) {
-    
+
     /* Loop through data within a logical bitstream */
-    eos = 0;    
+    eos = 0;
     while (!eos && !sig_request.exit) {
-      
+
       /* Check signals */
       if (sig_request.skipfile) {
 	eof = eos = 1;
 	break;
       }
 
-      if (sig_request.pause) {
+	if (options.remote) {
+	
+		/* run the playloop for the remote interface */
+		if (remote_playloop()) {
+			/* end song requested */
+			eof = eos = 1;
+			break;
+		}
+
+		/* Skip over audio */
+		handle_seek_opt(&options, decoder, format);
+	}
+
+	if (sig_request.pause) {
 	if (audio_buffer)
 	  buffer_thread_pause (audio_buffer);
 
@@ -529,11 +663,10 @@ void play (char *source_string)
 	eof = eos = 1;
 	break;
       } else if (ret < 0) {
-	status_error(_("Error: Decoding failure.\n"));
+	status_error(_("ERROR: Decoding failure.\n"));
 	break;
       }
 
-      
       /* Check to see if the audio format has changed */
       if (!audio_format_equal(&new_audio_fmt, &old_audio_fmt)) {
 	old_audio_fmt = new_audio_fmt;
@@ -545,13 +678,13 @@ void play (char *source_string)
 
 	reopen_arg = new_audio_reopen_arg(options.devices, &new_audio_fmt);
 
-	if (audio_buffer)	  
+	if (audio_buffer)
 	  buffer_insert_action_at_end(audio_buffer, &audio_reopen_action,
 				      reopen_arg);
 	else
 	  audio_reopen_action(NULL, reopen_arg);
       }
-      
+
 
       /* Update statistics display if needed */
       if (next_status <= 0) {
@@ -571,11 +704,15 @@ void play (char *source_string)
       do {
 	
 	if (nthc-- == 0) {
-	  if (audio_buffer)
-	    buffer_submit_data(audio_buffer, convbuffer, ret);
-	  else
+          if (audio_buffer) {
+            if (!buffer_submit_data(audio_buffer, convbuffer, ret)) {
+              status_error(_("ERROR: buffer write failed.\n"));
+              eof = eos = 1;
+              break;
+            }
+          } else
 	    audio_play_callback(convbuffer, ret, eos, &audio_play_arg);
-	  
+
 	  nthc = options.nth - 1;
 	}
 	
@@ -583,15 +720,15 @@ void play (char *source_string)
 	       ++ntimesc < options.ntimes);
 
       ntimesc = 0;
-            
+
     } /* End of data loop */
-    
+
   } /* End of logical bitstream loop */
-  
+
   /* Done playing this logical bitstream.  Clean up house. */
 
   if (audio_buffer) {
-    
+
     if (!sig_request.exit && !sig_request.skipfile) {
       buffer_mark_eos(audio_buffer);
       buffer_wait_for_empty(audio_buffer);
@@ -602,26 +739,14 @@ void play (char *source_string)
 
   /* Print final stats */
   display_statistics_quick(stat_format, audio_buffer, source, decoder); 
-   
-  
+
   format->cleanup(decoder);
   transport->close(source);
   status_reset_output_lock();  /* In case we were killed mid-output */
 
   status_message(1, _("Done."));
-  
+
   if (sig_request.exit)
-    exit (0);
+    exit (exit_status);
 }
 
-
-void exit_cleanup ()
-{
-      
-  if (audio_buffer != NULL) {
-    buffer_destroy (audio_buffer);
-    audio_buffer = NULL;
-  }
-
-  ao_onexit (options.devices);
-}
