@@ -11,7 +11,7 @@
  *                                                                  *
  ********************************************************************
  
- last mod: $Id: vorbis_comments.h 16825 2010-01-27 04:14:08Z xiphmont $
+ last mod: $Id$
  
 ********************************************************************/
 
@@ -22,7 +22,7 @@
 #include "format.h"
 
 
-void print_vorbis_comment (char *comment, decoder_callbacks_t *cb, 
+void print_vorbis_comment (const char *comment, decoder_callbacks_t *cb,
 			   void *callback_arg);
 
 #endif /* __VORBIS_COMMENTS_H__ */
